summaryrefslogtreecommitdiff
path: root/epan/tvbuff.h
diff options
context:
space:
mode:
authorGuy Harris <guy@alum.mit.edu>2017-01-09 22:18:49 -0800
committerGuy Harris <guy@alum.mit.edu>2017-01-10 06:19:37 +0000
commit7cd6906056922e4b8f68f1216d94eaa0809896fe (patch)
tree5a8c793f188ddda7f36a50369d00ff0de8f563e5 /epan/tvbuff.h
parent2a3b2360e15d49defde55240a5c1e171c7cade89 (diff)
downloadwireshark-7cd6906056922e4b8f68f1216d94eaa0809896fe.tar.gz
Rename tvb_new_subset() to tvb_new_subset_length_caplen().
This emphasizes that there is no such thing as *the* routine to construct a subset tvbuff; you need to choose one of tvb_new_subset_remaining() (if you want a new tvbuff that contains everything past a certain point in an existing tvbuff), tvb_new_subset_length() (if you want a subset that contains everything past a certain point, for some number of bytes, in an existing tvbuff), and tvb_new_subset_length_caplen() (for all other cases). Many of the calls to tvb_new_subset_length_caplen() should really be calling one of the other routines; that's the next step. (This also makes it easier to find the calls that need fixing.) Change-Id: Ieb3d676d8cda535451c119487d7cd3b559221f2b Reviewed-on: https://code.wireshark.org/review/19597 Reviewed-by: Guy Harris <guy@alum.mit.edu>
Diffstat (limited to 'epan/tvbuff.h')
-rw-r--r--epan/tvbuff.h8
1 files changed, 4 insertions, 4 deletions
diff --git a/epan/tvbuff.h b/epan/tvbuff.h
index 4ceb5a000e..1cd9c80124 100644
--- a/epan/tvbuff.h
+++ b/epan/tvbuff.h
@@ -75,7 +75,7 @@ typedef struct tvbuff tvbuff_t;
*
* A dissector:
* - Can chain new tvbs (subset, real, composite) to the
* tvb handed to the dissector using tvb_new_subset(),
* tvb_new_subset_length(), tvb_new_subset_remaining(),
* tvb_new_child_real_data(), tvb_set_child_real_data_tvbuff(),
* tvb_composite_finalize(), and tvb_child_uncompress(). (Composite
@@ -185,19 +185,19 @@ WS_DLL_PUBLIC tvbuff_t *tvb_new_real_data(const guint8 *data,
* Will throw BoundsError if 'backing_offset'/'length'
* is beyond the bounds of the backing tvbuff.
* Can throw ReportedBoundsError. */
-WS_DLL_PUBLIC tvbuff_t *tvb_new_subset(tvbuff_t *backing,
+WS_DLL_PUBLIC tvbuff_t *tvb_new_subset_length_caplen(tvbuff_t *backing,
const gint backing_offset, const gint backing_length,
const gint reported_length);
/**
* Similar to tvb_new_subset() but with captured length calculated
* to fit within the existing captured length and the specified
* backing length (which is used as the reported length).
* Can throw ReportedBoundsError. */
WS_DLL_PUBLIC tvbuff_t *tvb_new_subset_length(tvbuff_t *backing,
const gint backing_offset, const gint backing_length);
/** Similar to tvb_new_subset() but with backing_length and reported_length set
* to -1. Can throw ReportedBoundsError. */
WS_DLL_PUBLIC tvbuff_t *tvb_new_subset_remaining(tvbuff_t *backing,
const gint backing_offset);
@@ -75,7 +75,7 @@ typedef struct tvbuff tvbuff_t;
* A dissector:
* - Can chain new tvbs (subset, real, composite) to the
- * tvb handed to the dissector using tvb_new_subset(),
+ * tvb handed to the dissector using tvb_new_subset_length_caplen(),
* tvb_new_subset_length(), tvb_new_subset_remaining(),
* tvb_new_child_real_data(), tvb_set_child_real_data_tvbuff(),
@@ -185,19 +185,19 @@ WS_DLL_PUBLIC tvbuff_t *tvb_new_real_data(const guint8 *data,
const gint reported_length);
/**
- * Similar to tvb_new_subset() but with captured length calculated
+ * Similar to tvb_new_subset_length_caplen() but with captured length calculated
* to fit within the existing captured length and the specified
* backing length (which is used as the reported length).
@@ -185,19 +185,19 @@ WS_DLL_PUBLIC tvbuff_t *tvb_new_real_data(const guint8 *data,
WS_DLL_PUBLIC tvbuff_t *tvb_new_subset_length(tvbuff_t *backing,
const gint backing_offset, const gint backing_length);
-/** Similar to tvb_new_subset() but with backing_length and reported_length set
+/** Similar to tvb_new_subset_length_caplen() but with backing_length and reported_length set
* to -1. Can throw ReportedBoundsError. */
WS_DLL_PUBLIC tvbuff_t *tvb_new_subset_remaining(tvbuff_t *backing,